Name:    qblade
Summary: Wind Turbine Rotor Design and Simulation
Version: 0.96
Release: 4%{?dist}
Group:   Applications/Engineering
License: GPLv2+
URL:     http://www.q-blade.org/
Source0: https://sourceforge.net/projects/qblade/files/Source/QBlade_v%{version}_source.zip

## Fix QDataStream include files
Patch0:  qblade-qdatastream_header.patch

## Main building
BuildRequires: qt5-qtbase-devel
BuildRequires: qt5-qttools-devel
BuildRequires: libQGLViewer-qt5-devel
BuildRequires: eigen3-devel
BuildRequires: mesa-libGLU-devel
BuildRequires: desktop-file-utils
BuildRequires: dos2unix

%if 0%{?fedora}
BuildRequires: libappstream-glib
%endif

%description
QBlade is a Blade Element Momentum Method (BEM),
Double Multiple Streamtube (DMS) and nonlinear
Lifting Line Theory (LLT) Design and Simulation Software
for Vertical and Horizontal Axis Wind Turbines.
It also includes tools to setup and simulate the internal
blade structure and perform an aeroelastic analysis of a
wind turbine rotor in turbulent inflow conditions through
a coupling with FAST from NREL.

%prep
%setup -q -c QBlade_v%{version}_source

pushd src
for i in `find . -type f \( -name "*.cpp" -o -name "*.h" \)`; do
dos2unix -F -s -k -q $i
done
popd

#Remove bundled library and header files
rm -rf libs_* QGLViewer_headers win
rm -rf Eigen

%if %{?__isa_bits:%{__isa_bits}}%{!?__isa_bits:32} == 64
#nothing
%else
sed -e 's|#CONFIG += build32bit|CONFIG += build32bit|g' -i %{name}_v09.pro
sed -e 's|CONFIG += build64bit||g' -i %{name}_v09.pro
%endif
sed -e 's|$$PWD/libs_unix_32bit|%{_libdir}|g' -i %{name}_v09.pro
sed -e 's|$$PWD/libs_unix_64bit|%{_libdir}|g' -i %{name}_v09.pro
%if 0%{?fedora}
sed -e 's|-lQGLViewer|-lQGLViewer-qt5|g' -i %{name}_v09.pro
%endif

%build
mkdir build && cd build
%{qmake_qt5} ../%{name}_v09.pro \
 QMAKE_CFLAGS_RELEASE="$RPM_OPT_FLAGS" \
 QMAKE_CXXFLAGS_RELEASE="$RPM_OPT_FLAGS" \
 QMAKE_LFLAGS="$RPM_LD_FLAGS" \
 INCLUDEPATH+="%{_includedir}/QGLViewer %{_includedir}/eigen3/Eigen %{_includedir}/eigen3"
make %{?_smp_mflags}

%install
#Manual installation

mkdir -p %{buildroot}%{_datadir}/icons/%{name}
install -pm 644 images/qblade600.png %{buildroot}%{_datadir}/icons/%{name}/qblade.png

mkdir -p %{buildroot}%{_bindir}
install -pm 755 build/QBlade %{buildroot}%{_bindir}

##Make a .desktop file
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Name=QBlade %{version}
Type=Application
Comment=Wind Turbine Rotor Design and Simulation
TryExec=QBlade
Exec=QBlade
Categories=Education;Science;DataVisualization;
Icon=%{_datadir}/icons/%{name}/qblade.png
EOF

mkdir -p %{buildroot}%{_datadir}/appdata
cat > %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<component type="desktop">
  <id type="desktop">%{name}.desktop</id>
  <metadata_license>CC0-1.0</metadata_license>
  <summary>Wind Turbine Rotor Design and Simulation</summary>
  <name>%{name}</name>
  <project_license>GPL-2.0+</project_license>
  <categories>
   <category>Education</category>
   <category>Science</category>
  </categories>
  <description> 
    <p>
       QBlade is a Blade Element Momentum Method (BEM),
       Double Multiple Streamtube (DMS) and nonlinear
       Lifting Line Theory (LLT) Design and Simulation Software
       for Vertical and Horizontal Axis Wind Turbines.
       It also includes tools to setup and simulate the internal
       blade structure and perform an aeroelastic analysis of a
       wind turbine rotor in turbulent inflow conditions through
       a coupling with FAST from NREL.
    </p>
  </description>
  <url type="homepage">http://www.q-blade.org/</url>
  <screenshots>
    <screenshot type="default">
     <image>https://sagitter.fedorapeople.org/qblade/qblade1.png</image>
    </screenshot>
  </screenshots>
  <updatecontact>sagitter_at_fedoraproject.org</updatecontact>
</component>
EOF

%post
/bin/touch --no-create %{_datadir}/icons/%{name} &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/%{name} &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/%{name} &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/%{name} &>/dev/null || :

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/*.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%license License.txt
%doc doc/*.odt doc/OpenCL_Linux.txt
%{_bindir}/QBlade
%{_datadir}/icons/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.96-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.96-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Dec 29 2016 Rich Mattes <richmattes@gmail.com> - 0.96-2
- Rebuild for eigen3-3.3.1

* Thu Aug 18 2016 Antonio Trande <sagitter@fedoraproject.org> - 0.96-1
- Update to 0.96

* Sat Jul 16 2016 Antonio Trande <sagitter@fedoraproject.org> - 0.95-3
- Rebuild for libQGLViewer

* Sat Jun 18 2016 Antonio Trande <sagitter@fedoraproject.org> - 0.95-2
- Fix sed command

* Sat Jun 18 2016 Antonio Trande <sagitter@fedoraproject.org> - 0.95-1
- Update to 0.95

* Sat May 21 2016 Antonio Trande <sagitter@fedoraproject.org> - 0.91-1
- Unbundle Eigen
- Version changed to 0.91

* Wed Apr 13 2016 Antonio Trande <sagitter@fedoraproject.org> - 0.9.1-1
- First package
